testing Package
===============

:mod:`testing` Package
----------------------

.. automodule:: numba.testing
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`doctest_support` Module
-----------------------------

.. automodule:: numba.testing.doctest_support
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`runner` Module
--------------------

.. automodule:: numba.testing.runner
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_support` Module
--------------------------

.. automodule:: numba.testing.test_support
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`user_support` Module
--------------------------

.. automodule:: numba.testing.user_support
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.testing.tests

